SQLAlchemy 0.4 Documentation - module sqlalchemy.sql

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4 Last Updated: 08/22/07 15:48:11

### module sqlalchemy.sql

### Module Functions

def alias(selectable, alias=None)

Return an Alias object.

An `Alias` represents any FromClause with an alternate name assigned within SQL, typically using the `AS` clause when generated, e.g. `SELECT * FROM table AS aliasname`.

Similar functionality is available via the `alias()` method available on all `FromClause` subclasses.

> selectable
>   any `FromClause` subclass, such as a table, select statement, etc..
> alias
>   string name to be assigned as the alias. If `None`, a random name will be generated.

def and_(*clauses)

Join a list of clauses together using the `AND` operator.

The `&` operator is also overloaded on all _CompareMixin subclasses to produce the same result.

def asc(column)

Return an ascending `ORDER BY` clause element.

e.g.:

    order_by = [asc(table1.mycol)]

def between(ctest, cleft, cright)

Return a `BETWEEN` predicate clause.

Equivalent of SQL `clausetest BETWEEN clauseleft AND clauseright`.

The `between()` method on all _CompareMixin subclasses provides similar functionality.

def bindparam(key, value=None, type_=None, shortname=None, unique=False)

Create a bind parameter clause with the given key.

value
  a default value for this bind parameter. a bindparam with a value is called a `value-based bindparam`.
shortname
  an `alias` for this bind parameter. usually used to alias the `key` nd `label` of a column, i.e. `somecolname` and `sometable_somecolname`
type
  a sqlalchemy.types.TypeEngine object indicating the type of this bind param, will invoke type-specific bind parameter processing
unique
  if True, bind params sharing the same name will have their underlying `key` modified to a uniquely generated name. mostly useful with value-based bind params.

def case(whens, value=None, else_=None)

Produce a `CASE` statement.

whens
  A sequence of pairs to be translated into "when / then" clauses.
value
  Optional for simple case statements.
else_
  Optional as well, for case defaults.

def cast(clause, totype, **kwargs)

Return a `CAST` function.

Equivalent of SQL `CAST(clause AS totype)`.

Use with a TypeEngine subclass, i.e:

    cast(table.c.unit_price * table.c.qty, Numeric(10,4))

or:

    cast(table.c.timestamp, DATE)

def column(text, type_=None)

Return a textual column clause, as would be in the columns clause of a `SELECT` statement.

The object returned is an instance of _ColumnClause, which represents the "syntactical" portion of the schema-level Column object.

text
  the name of the column. Quoting rules will be applied to the clause like any other column name. For textual column constructs that are not to be quoted, use the literal_column() function.
type_
  an optional TypeEngine object which will provide result-set translation for this column.

def delete(table, whereclause=None, **kwargs)

Return a Delete clause element.

Similar functionality is available via the `delete()` method on Table.

table
  The table to be updated.
whereclause
  A `ClauseElement` describing the `WHERE` condition of the `UPDATE` statement.

def desc(column)

Return a descending `ORDER BY` clause element.

e.g.:

    order_by = [desc(table1.mycol)]

def distinct(expr)

Return a `DISTINCT` clause.

def except_(*selects, **kwargs)

Return an `EXCEPT` of multiple selectables.

The returned object is an instance of CompoundSelect.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def except_all(*selects, **kwargs)

Return an `EXCEPT ALL` of multiple selectables.

The returned object is an instance of CompoundSelect.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def exists(*args, **kwargs)

Return an `EXISTS` clause as applied to a Select object.

The resulting _Exists object can be executed by itself or used as a subquery within an enclosing select.

*args, **kwargs
  all arguments are sent directly to the select() function to produce a `SELECT` statement.

def extract(field, expr)

Return the clause `extract(field FROM expr)`.

def insert(table, values=None, **kwargs)

Return an Insert clause element.

Similar functionality is available via the `insert()` method on Table.

table
  The table to be inserted into.
values
  A dictionary which specifies the column specifications of the `INSERT`, and is optional. If left as None, the column specifications are determined from the bind parameters used during the compile phase of the `INSERT` statement. If the bind parameters also are None during the compile phase, then the column specifications will be generated from the full list of table columns.

If both values and compile-time bind parameters are present, the compile-time bind parameters override the information specified within values on a per-key basis.

The keys within values can be either `Column` objects or their string identifiers. Each key may reference one of:

- a literal data value (i.e. string, number, etc.);
- a Column object;
- a SELECT statement.

If a `SELECT` statement is specified which references this `INSERT` statement's table, the statement will be correlated against the `INSERT` statement.

def intersect(*selects, **kwargs)

Return an `INTERSECT` of multiple selectables.

The returned object is an instance of CompoundSelect.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def intersect_all(*selects, **kwargs)

Return an `INTERSECT ALL` of multiple selectables.

The returned object is an instance of CompoundSelect.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def join(left, right, onclause=None, **kwargs)

Return a `JOIN` clause element (regular inner join).

The returned object is an instance of Join.

Similar functionality is also available via the `join()` method on any FromClause.

left
  The left side of the join.
right
  The right side of the join.
onclause
  Optional criterion for the `ON` clause, is derived from foreign key relationships established between left and right otherwise.

To chain joins together, use the `join()` or `outerjoin()` methods on the resulting `Join` object.

def literal(value, type_=None)

Return a literal clause, bound to a bind parameter.

Literal clauses are created automatically when non- `ClauseElement` objects (such as strings, ints, dates, etc.) are used in a comparison operation with a _CompareMixin subclass, such as a `Column` object. Use this function to force the generation of a literal clause, which will be created as a _BindParamClause with a bound value.

value
  the value to be bound. Can be any Python object supported by the underlying DB-API, or is translatable via the given type argument.
type_
  an optional TypeEngine which will provide bind-parameter translation for this literal.

def literal_column(text, type_=None)

Return a textual column clause, as would be in the columns clause of a `SELECT` statement.

The object returned is an instance of _ColumnClause, which represents the "syntactical" portion of the schema-level Column object.

text
  the name of the column. Quoting rules will not be applied to the column. For textual column constructs that should be quoted like any other column construct, use the column() function.
type
  an optional TypeEngine object which will provide result-set translation for this column.

def not_(clause)

Return a negation of the given clause, i.e. `NOT(clause)`.

The `~` operator is also overloaded on all _CompareMixin subclasses to produce the same result.

def null()

Return a `_Null` object, which compiles to `NULL` in a sql statement.

def or_(*clauses)

Join a list of clauses together using the `OR` operator.

The `|` operator is also overloaded on all _CompareMixin subclasses to produce the same result.

def outerjoin(left, right, onclause=None, **kwargs)

Return an `OUTER JOIN` clause element.

The returned object is an instance of Join.

Similar functionality is also available via the `outerjoin()` method on any FromClause.

left
  The left side of the join.
right
  The right side of the join.
onclause
  Optional criterion for the `ON` clause, is derived from foreign key relationships established between left and right otherwise.

To chain joins together, use the `join()` or `outerjoin()` methods on the resulting `Join` object.

def outparam(key, type_=None)

Create an 'OUT' parameter for usage in functions (stored procedures), for databases which support them.

The `outparam` can be used like a regular function parameter. The "output" value will be available from the ResultProxy object via its `out_parameters` attribute, which returns a dictionary containing the values.

def select(columns=None, whereclause=None, from_obj=[], **kwargs)

Returns a `SELECT` clause element.

Similar functionality is also available via the `select()` method on any FromClause.

The returned object is an instance of Select.

All arguments which accept `ClauseElement` arguments also accept string arguments, which will be converted as appropriate into either `text()` or `literal_column()` constructs.

columns

  A list of `ClauseElement` objects, typically `ColumnElement` objects or subclasses, which will form the columns clause of the resulting statement. For all members which are instances of `Selectable`, the individual `ColumnElement` members of the `Selectable` will be added individually to the columns clause. For example, specifying a `Table` instance will result in all the contained `Column` objects within to be added to the columns clause.

  This argument is not present on the form of `select()` available on `Table`.

whereclause
  A `ClauseElement` expression which will be used to form the `WHERE` clause.
from_obj
  A list of `ClauseElement` objects which will be added to the `FROM` clause of the resulting statement. Note that "from" objects are automatically located within the columns and whereclause ClauseElements. Use this parameter to explicitly specify "from" objects which are not automatically locatable. This could include `Table` objects that aren't otherwise present, or `Join` objects whose presence will supercede that of the `Table` objects already located in the other clauses.
**kwargs

  Additional parameters include:

  prefixes
    a list of strings or `ClauseElement` objects to include directly after the SELECT keyword in the generated statement, for dialect-specific query features.
  distinct=False
    when `True`, applies a `DISTINCT` qualifier to the columns clause of the resulting statement.
  use_labels=False
    when `True`, the statement will be generated using labels for each column in the columns clause, which qualify each column with its parent table's (or aliases) name so that name conflicts between columns in different tables don't occur. The format of the label is <tablename>_<column>. The "c" collection of the resulting `Select` object will use these names as well for targeting column members.
  for_update=False
    when `True`, applies `FOR UPDATE` to the end of the resulting statement. Certain database dialects also support alternate values for this parameter, for example mysql supports "read" which translates to `LOCK IN SHARE MODE`, and oracle supports "nowait" which translates to `FOR UPDATE NOWAIT`.
  correlate=True
    indicates that this `Select` object should have its contained `FromClause` elements "correlated" to an enclosing `Select` object. This means that any `ClauseElement` instance within the "froms" collection of this `Select` which is also present in the "froms" collection of an enclosing select will not be rendered in the `FROM` clause of this select statement.
  group_by
    a list of `ClauseElement` objects which will comprise the `GROUP BY` clause of the resulting select.
  having
    a `ClauseElement` that will comprise the `HAVING` clause of the resulting select when `GROUP BY` is used.
  order_by
    a scalar or list of `ClauseElement` objects which will comprise the `ORDER BY` clause of the resulting select.
  limit=None
    a numerical value which usually compiles to a `LIMIT` expression in the resulting select. Databases that don't support `LIMIT` will attempt to provide similar functionality.
  offset=None
    a numeric value which usually compiles to an `OFFSET` expression in the resulting select. Databases that don't support `OFFSET` will attempt to provide similar functionality.
  bind=None
    an `Engine` or `Connection` instance to which the resulting `Select ` object will be bound. The ``Select` object will otherwise automatically bind to whatever `Connectable` instances can be located within its contained `ClauseElement` members.
  scalar=False
    deprecated. Use select(...).as_scalar() to create a "scalar column" proxy for an existing Select object.

def subquery(alias, *args, **kwargs)

Return an Alias object derived from a Select.

name
  alias name

*args, **kwargs

> all other arguments are delivered to the select() function.

def table(name, *columns)

Return a Table object.

This is a primitive version of the Table object, which is a subclass of this object.

def text(text, bind=None, *args, **kwargs)

Create literal text to be inserted into a query.

When constructing a query from a `select()`, `update()`, `insert()` or `delete()`, using plain strings for argument values will usually result in text objects being created automatically. Use this function when creating textual clauses outside of other `ClauseElement` objects, or optionally wherever plain text is to be used.

text
  the text of the SQL statement to be created. use `:<param>` to specify bind parameters; they will be compiled to their engine-specific format.
bind
  an optional connection or engine to be used for this text query.
bindparams
  a list of `bindparam()` instances which can be used to define the types and/or initial values for the bind parameters within the textual statement; the keynames of the bindparams must match those within the text of the statement. The types will be used for pre-processing on bind values.
typemap
  a dictionary mapping the names of columns represented in the `SELECT` clause of the textual statement to type objects, which will be used to perform post-processing on columns within the result set (for textual statements that produce result sets).

def union(*selects, **kwargs)

Return a `UNION` of multiple selectables.

The returned object is an instance of CompoundSelect.

A similar `union()` method is available on all FromClause subclasses.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def union_all(*selects, **kwargs)

Return a `UNION ALL` of multiple selectables.

The returned object is an instance of CompoundSelect.

A similar `union_all()` method is available on all FromClause subclasses.

*selects
  a list of Select instances.
**kwargs
  available keyword arguments are the same as those of select().

def update(table, whereclause=None, values=None, **kwargs)

Return an Update clause element.

Similar functionality is available via the `update()` method on Table.

table
  The table to be updated.
whereclause
  A `ClauseElement` describing the `WHERE` condition of the `UPDATE` statement.
values
  A dictionary which specifies the `SET` conditions of the `UPDATE`, and is optional. If left as None, the `SET` conditions are determined from the bind parameters used during the compile phase of the `UPDATE` statement. If the bind parameters also are None during the compile phase, then the `SET` conditions will be generated from the full list of table columns.

If both values and compile-time bind parameters are present, the compile-time bind parameters override the information specified within values on a per-key basis.

The keys within values can be either `Column` objects or their string identifiers. Each key may reference one of:

- a literal data value (i.e. string, number, etc.);
- a Column object;
- a SELECT statement.

If a `SELECT` statement is specified which references this `UPDATE` statement's table, the statement will be correlated against the `UPDATE` statement.

### class Alias(FromClause)

Represents an table or selectable alias (AS).

Represents an alias, as typically applied to any table or sub-select within a SQL statement using the `AS` keyword (or without the keyword on certain databases such as Oracle).

This object is constructed from the `alias()` module level function as well as the `alias()` method available on all `FromClause` subclasses.

def __init__(self, selectable, alias=None)

Construct a new `Alias`.

bind = property()
def get_children(self, **kwargs)
def is_derived_from(self, fromclause)
def named_with_column(self)
def supports_execution(self)
back to section top

### class ClauseElement(object)

Base class for elements of a programmatically constructed SQL expression.

bind = property()

Returns the Engine or Connection to which this ClauseElement is bound, or None if none found.

def compare(self, other)

Compare this ClauseElement to the given ClauseElement.

Subclasses should override the default behavior, which is a straight identity comparison.

def compile(self, bind=None, parameters=None, compiler=None, dialect=None)

Compile this SQL expression.

Uses the given `Compiler`, or the given `AbstractDialect` or `Engine` to create a `Compiler`. If no compiler arguments are given, tries to use the underlying `Engine` this `ClauseElement` is bound to to create a `Compiler`, if any.

Finally, if there is no bound `Engine`, uses an `DefaultDialect` to create a default `Compiler`.

parameters is a dictionary representing the default bind parameters to be used with the statement. If parameters is a list, it is assumed to be a list of dictionaries and the first dictionary in the list is used with which to compile against.

The bind parameters can in some cases determine the output of the compilation, such as for `UPDATE` and `INSERT` statements the bind parameters that are present determine the `SET` and `VALUES` clause of those statements.

def execute(self, *multiparams, **params)

Compile and execute this `ClauseElement`.

def get_children(self, **kwargs)

Return immediate child elements of this `ClauseElement`.

This is used for visit traversal.

**kwargs may contain flags that change the collection that is returned, for example to return a subset of items in order to cut down on larger traversals, or to return child items from a different context (such as schema-level collections instead of clause-level).

def params(self, *optionaldict, **kwargs)

Return a copy with `bindparam()` elments replaced.

Returns a copy of this ClauseElement with `bindparam()` elements replaced with values taken from the given dictionary:

    >>> clause = column('x') + bindparam('foo')
    >>> print clause.compile().params
    {'foo':None}
    >>> print clause.params({'foo':7}).compile().params
    {'foo':7}

def scalar(self, *multiparams, **params)

Compile and execute this `ClauseElement`, returning the result's scalar representation.

def self_group(self, against=None)
def supports_execution(self)

Return True if this clause element represents a complete executable statement.

def unique_params(self, *optionaldict, **kwargs)

Return a copy with `bindparam()` elments replaced.

Same functionality as `params()`, except adds unique=True to affected bind parameters so that multiple statements can be used.

def __and__(self, other)
def __invert__(self)
def __or__(self, other)
back to section top

### class ClauseVisitor(object)

A class that knows how to traverse and visit `ClauseElements`.

Calls visit_XXX() methods dynamically generated for each particualr `ClauseElement` subclass encountered. Traversal of a hierarchy of `ClauseElements` is achieved via the `traverse()` method, which is passed the lead `ClauseElement`.

By default, `ClauseVisitor` traverses all elements fully. Options can be specified at the class level via the `__traverse_options__` dictionary which will be passed to the `get_children()` method of each `ClauseElement`; these options can indicate modifications to the set of elements returned, such as to not return column collections (column_collections=False) or to return Schema-level items (schema_visitor=True).

`ClauseVisitor` also supports a simultaneous copy-and-traverse operation, which will produce a copy of a given `ClauseElement` structure while at the same time allowing `ClauseVisitor` subclasses to modify the new structure in-place.

def chain(self, visitor)

'chain' an additional ClauseVisitor onto this ClauseVisitor.

the chained visitor will receive all visit events after this one.

def iterate(self, obj, stop_on=None)
def traverse(self, obj, stop_on=None, clone=False)
def traverse_single(self, obj, **kwargs)
back to section top

### class ColumnCollection(OrderedProperties)

An ordered dictionary that stores a list of ColumnElement instances.

Overrides the `__eq__()` method to produce SQL clauses between sets of correlated columns.

def __init__(self, *cols)

Construct a new `ColumnCollection`.

def add(self, column)

Add a column to this collection.

The key attribute of the column will be used as the hash key for this dictionary.

def contains_column(self, col)
def extend(self, iter)
def remove(self, column)
def __contains__(self, other)
def __eq__(self, other)
back to section top

### class ColumnElement(ClauseElement,_CompareMixin)

Represent an element that is usable within the "column clause" portion of a `SELECT` statement.

This includes columns associated with tables, aliases, and subqueries, expressions, function calls, SQL keywords such as `NULL`, literals, etc. `ColumnElement` is the ultimate base class for all such elements.

`ColumnElement` supports the ability to be a proxy element, which indicates that the `ColumnElement` may be associated with a `Selectable` which was derived from another `Selectable`. An example of a "derived" `Selectable` is an `Alias` of a `Table`.

A `ColumnElement`, by subclassing the `_CompareMixin` mixin class, provides the ability to generate new `ClauseElement` objects using Python expressions. See the `_CompareMixin` docstring for more details.

foreign_key = property()
foreign_keys = property()

Foreign key accessor. References a list of `ForeignKey` objects which each represent a foreign key placed on this column's ultimate ancestor.

orig_set = property()

A Set containing TableClause-bound, non-proxied ColumnElements for which this ColumnElement is a proxy. In all cases except for a column proxied from a Union (i.e. CompoundSelect), this set will be just one element.

primary_key = property()

Primary key flag. Indicates if this `Column` represents part or whole of a primary key for its parent table.

def shares_lineage(self, othercolumn)

Return True if the given `ColumnElement` has a common ancestor to this `ColumnElement`.

back to section top

### class CompoundSelect(_SelectBaseMixin,FromClause)

def __init__(self, keyword, *selects, **kwargs)

Construct a new `CompoundSelect`.

def get_children(self, column_collections=True, **kwargs)
name = property()
def self_group(self, against=None)
back to section top

### class Delete(_UpdateBase)

def __init__(self, table, whereclause)

Construct a new `Delete`.

def get_children(self, **kwargs)
back to section top

### class FromClause(Selectable)

Represent an element that can be used within the `FROM` clause of a `SELECT` statement.

def __init__(self, name=None)

Construct a new `FromClause`.

def alias(self, name=None)
c = property()
columns = property()
def corresponding_column(self, column, raiseerr=True, keys_ok=False, require_embedded=False)

Given a `ColumnElement`, return the exported `ColumnElement` object from this `Selectable` which corresponds to that original `Column` via a common anscestor column.

column
  the target `ColumnElement` to be matched
raiseerr
  if True, raise an error if the given `ColumnElement` could not be matched. if False, non-matches will return None.
keys_ok
  if the `ColumnElement` cannot be matched, attempt to match based on the string "key" property of the column alone. This makes the search much more liberal.
require_embedded
  only return corresponding columns for the given `ColumnElement`, if the given `ColumnElement` is actually present within a sub-element of this `FromClause`. Normally the column will match if it merely shares a common anscestor with one of the exported columns of this `FromClause`.

def count(self, whereclause=None, **params)
def default_order_by(self)
foreign_keys = property()
def is_derived_from(self, fromclause)

Return True if this FromClause is 'derived' from the given FromClause.

An example would be an Alias of a Table is derived from that Table.

def join(self, right, *args, **kwargs)
def named_with_column(self)

True if the name of this FromClause may be prepended to a column in a generated SQL statement.

oid_column = property()
original_columns = property()

A dictionary mapping an original Table-bound column to a proxied column in this FromClause.

def outerjoin(self, right, *args, **kwargs)
primary_key = property()
def replace_selectable(self, old, alias)

replace all occurences of FromClause 'old' with the given Alias object, returning a copy of this `FromClause`.

back to section top

### class Insert(_UpdateBase)

def __init__(self, table, values=None)

Construct a new `Insert`.

def get_children(self, **kwargs)
def values(self, v)
back to section top

### class Join(FromClause)

represent a `JOIN` construct between two `FromClause` elements.

The public constructor function for `Join` is the module-level `join()` function, as well as the `join()` method available off all `FromClause` subclasses.

def __init__(self, left, right, onclause=None, isouter=False)

Construct a new `Join`.

def alias(self, name=None)

Create a `Select` out of this `Join` clause and return an `Alias` of it.

The `Select` is not correlating.

bind = property()
encodedname = property()
folded_equivalents = property()

Returns the column list of this Join with all equivalently-named, equated columns folded into one column, where 'equated' means they are equated to each other in the ON clause of this join.

def get_children(self, **kwargs)
name = property()
primary_key = property()
def select(self, whereclause=None, fold_equivalents=False, **kwargs)

Create a `Select` from this `Join`.

whereclause
  the WHERE criterion that will be sent to the `select()` function
fold_equivalents
  based on the join criterion of this `Join`, do not include repeat column names in the column list of the resulting select, for columns that are calculated to be "equivalent" based on the join criterion of this `Join`. This will recursively apply to any joins directly nested by this one as well.
**kwargs
  all other kwargs are sent to the underlying `select()` function. See the `select()` module level function for details.

def self_group(self, against=None)
back to section top

### class NoColumnVisitor(ClauseVisitor)

a ClauseVisitor that will not traverse the exported Column collections on Table, Alias, Select, and CompoundSelect objects (i.e. their 'columns' or 'c' attribute).

this is useful because most traversals don't need those columns, or in the case of DefaultCompiler it traverses them explicitly; so skipping their traversal here greatly cuts down on method call overhead.

back to section top

### class Select(_SelectBaseMixin,FromClause)

Represents a `SELECT` statement.

Select statements support appendable clauses, as well as the ability to execute themselves and return a result set.

def __init__(self, columns, whereclause=None, from_obj=None, distinct=False, having=None, correlate=True, prefixes=None, **kwargs)

Construct a Select object.

The public constructor for Select is the select() function; see that function for argument descriptions.

def append_column(self, column, copy_collection=True)
def append_correlation(self, fromclause, copy_collection=True)
def append_from(self, fromclause, copy_collection=True)
def append_having(self, having)
def append_prefix(self, clause, copy_collection=True)
def append_whereclause(self, whereclause)
def column(self, column)
def correlate(self, fromclause)
def distinct(self)
def except_(self, other, **kwargs)
def except_all(self, other, **kwargs)
froms = property()

Return a list of all FromClause elements which will be applied to the FROM clause of the resulting statement.

def get_children(self, column_collections=True, **kwargs)
def having(self, having)
inner_columns = property()
def intersect(self, other, **kwargs)
def intersect_all(self, other, **kwargs)
def locate_all_froms(self)
name = property()
def prefix_with(self, clause)
def select_from(self, fromclause)
def self_group(self, against=None)
def union(self, other, **kwargs)
def union_all(self, other, **kwargs)
def where(self, whereclause)
back to section top

### class Selectable(ClauseElement)

Represent a column list-holding object.

This is the common base class of ColumnElement and FromClause. The reason `ColumnElement` is marked as a "list-holding" object is so that it can be treated similarly to `FromClause` in column-selection scenarios; it contains a list of columns consisting of itself.

columns = property()

a ColumnCollection containing `ColumnElement` instances.

def select(self, whereclauses=None, **params)
back to section top

### class TableClause(FromClause)

Represents a "table" construct.

Note that this represents tables only as another syntactical construct within SQL expressions; it does not provide schema-level functionality.

def __init__(self, name, *columns)

Construct a new `TableClause`.

def alias(self, name=None)
def append_column(self, c)
def count(self, whereclause=None, **params)
def delete(self, whereclause=None)
def get_children(self, column_collections=True, **kwargs)
def insert(self, values=None)
def join(self, right, *args, **kwargs)
def named_with_column(self)
original_columns = property()
def outerjoin(self, right, *args, **kwargs)
def select(self, whereclause=None, **params)
def update(self, whereclause=None, values=None)
back to section top

### class Update(_UpdateBase)

def __init__(self, table, whereclause, values=None)

Construct a new `Update`.

def get_children(self, **kwargs)
def values(self, v)
back to section top